@@ -6,6 +6,7 @@
 from .colors import *
 from .plot import *
 from .style import *
-from .text import *
+from .texts import *
+from .subplots import *
 
-__version__ = '0.5.0'
+__version__ = '0.7.0'
